@@ -3,6 +3,7 @@ monkey.patch_all()
 import logging
 import click
 import sys
+import signal
 import os.path
 
 from .config import Config
@@ -22,6 +23,7 @@ def main(ctx, config, log_level):
     log_level = getattr(logging, log_level)
     logging.basicConfig(level=log_level)
     logging.getLogger('kafka').setLevel(logging.WARN)
+    logging.getLogger('requests.packages.urllib3.connectionpool').setLevel(logging.WARN)
 
 
 @main.command()
@@ -35,6 +37,14 @@ def run(config):
     state_manager = StateManager(config.state_dir())
     tasks = [config.load_task(x) for x in config.tasks()]
     c = TaskContainer(config.kafka_hosts, tasks, state_manager, config)
+
+    def print_stats(signum, frame):
+        print "Current stats:"
+        import gevent
+        gevent.spawn(c.print_stats)
+
+    signal.signal(signal.SIGUSR1, print_stats)
+
     c.run()
 
 
